import React, { PureComponent } from 'react';
import { Table, Button } from 'antd';
import PropTypes from 'prop-types';
import { cloneDeep } from 'lodash';

const ButtonGroup = Button.Group;

export default class SelTable extends PureComponent {
  static propTypes = {
    dataSource: PropTypes.array.isRequired,   // 表的数据源
    columns: PropTypes.array.isRequired,      // 表的列的结构
    rowKeyName: PropTypes.string.isRequired,  // table row key name
    operSort: PropTypes.bool,                 // 开启排序功能
    operDel: PropTypes.bool,                  // 开启删除功能
    onUp: PropTypes.func,                     // 点击向上调整位置
    onDown: PropTypes.func,                   // 点击向下调整位置
  };

  render() {
    const { operSort, operDel, columns, dataSource, rowKeyName, onUp, onDown, onDel, ...rest } = this.props;
    // 防止污染原始数据
    const curSpaceColumns = cloneDeep(columns);

    const sortColumn = {
      title: '排序',
      dataIndex: 'sort-operation',
      key: 'sort-operation',
      render: (text, record) => (
        <ButtonGroup>
          <Button onClick={() => onUp(record)} size="small" icon="up-circle-o"></Button>
          <Button onClick={() => onDown(record)} size="small" icon="down-circle-o"></Button>
        </ButtonGroup>
      ),
    };

    const delColumn = {
      title: '删除',
      dataIndex: 'del-operation',
      key: 'del-operation',
      render: (text, record) => (
        <Button onClick={() => onDel(record)} size="small" icon="delete"></Button>
      ),
    };

    if (operSort) {
      curSpaceColumns.push(sortColumn);
    }

    if (operDel) {
      curSpaceColumns.push(delColumn);
    }

    return (
      <Table
        bordered={true}
        dataSource={dataSource}
        columns={curSpaceColumns}
        rowKey={rowKeyName}
        {...rest}
      />
    );
  }
}
