import React, { PureComponent } from 'react';
import Hls from 'hls.js';

export default class VideoPlayer extends PureComponent {
  constructor(props) {
    super(props);
    this.state = {
      isMuted: false,       //无声/有声
      isPlaying: false,
      playerId: Date.now(),
    };
    this.hls = null;
    this.playVideo = this.playVideo.bind(this);
  }

  componentDidMount() {
    this._initPlayer();
  }

  componentWillUnmount() {
    if(this.hls) {
      this.hls.destroy();
    }
  }

  componentWillReceiveProps(nextProps) {
    if (nextProps.isPaused) {
      this.refs.video.pause();
    }
  }

  playVideo() {
    let { video : $video } = this.refs;
    $video.play();

    this.setState({isPlaying: true});
  }

  _initPlayer () {
    if(this.hls) {
      this.hls.destroy();
    }

    let { url, autoplay, hlsConfig, m3u8 } = this.props;
    if (!m3u8) return;

    let { video : $video } = this.refs;
    let hls = new Hls(hlsConfig);

    hls.attachMedia($video);

    hls.on(Hls.Events.MEDIA_ATTACHED, () => {
      hls.loadSource(url);

      hls.on(Hls.Events.MANIFEST_PARSED, () => {
        if(autoplay) {
          $video.play();
        }
        else {
          $video.pause();
        }
      });
    });

    this.hls = hls;
  }

  render() {
    let { isMuted, isPlaying, playerId } = this.state;
    let { controls, width, height, url } = this.props;

    return (
      <div key={playerId}>
        {!isPlaying &&
          <span onClick={this.playVideo}></span>
        }
        <video ref="video"
          id={`react-hls-${playerId}`}
          src={url}
          controls={controls}
          width={width}
          height={height}
          muted={isMuted}
          playsInline>
        </video>
      </div>
    );
  }
}
