import pathToRegexp from 'path-to-regexp';
import { message } from 'antd';
import { queryOne, create, update, queryMerchantRecommend, updateMerchantRecommend } from '../../services/merchant';

export default {
  namespace: 'merchantDetail',

  state: {
    filters: {},
    operType: 'create',
    currentItem: {},
    itemLoading: false,
    recommend: [],
    recLoading: false,
    recModalShow: false,
  },

  subscriptions: {
    setup({ dispatch, history }) {
      history.listen(({ pathname, state }) => {
        const match = pathToRegexp('/merchant/edit/:id').exec(pathname);
        if (match) {
          dispatch({ type: 'query', payload: { id: match[1] } });
          dispatch({ type: 'saveFilters', payload: state });
          dispatch({
            type: 'saveOperType',
            payload: { operType: 'update' },
          });
        }
        if (pathname === '/merchant/add') {
          dispatch({ type: 'saveFilters', payload: state });
          dispatch({
            type: 'saveOperType',
            payload: { operType: 'create' },
          });
        }
      });
    },
  },

  effects: {
    * query({ payload }, { call, put }) {
      yield put({ type: 'changeLoading', payload: { itemLoading: true } });
      const { data, success } = yield call(queryOne, payload);
      if (success) {
        yield put({ type: 'querySuccess', payload: data });
      }
      yield put({ type: 'changeLoading', payload: { itemLoading: false } });
    },
    * create({ payload, callback }, { call }) {
      const { success } = yield call(create, payload);
      if (success) {
        message.success('创建成功!');
        if (callback) callback();
      }
    },
    * update({ payload, callback }, { call, put }) {
      const { success } = yield call(update, payload);
      if (success) {
        message.success('修改成功!');
        if (callback) callback();
        yield put({ type: 'clearCache', payload: { currentItem: {} } });
      }
    },
    * queryMerchantRecommend({ payload }, { call, put }) {
      yield put({ type: 'changeLoading', payload: { recLoading: true } });
      const { data, success } = yield call(queryMerchantRecommend, payload);
      if (success) {
        yield put({ type: 'queryRecommendSuccess', payload: data });
      }
      yield put({ type: 'changeLoading', payload: { recLoading: false } });
    },
    * updateMerchantRecommend({ payload, callback }, { call, put }) {
      const { success } = yield call(updateMerchantRecommend, payload);
      if (success) {
        message.success('修改成功!');
        if (callback) callback();
        yield put({ type: 'clearCache', payload: { recommend: [] } });
      }
    },
  },

  reducers: {
    changeLoading(state, action) {
      return { ...state, ...action.payload };
    },
    querySuccess(state, action) {
      return { ...state, currentItem: action.payload };
    },
    queryRecommendSuccess(state, action) {
      return { ...state, recommend: action.payload };
    },
    saveFilters(state, action) {
      return { ...state, filters: action.payload };
    },
    saveOperType(state, action) {
      return { ...state, ...action.payload };
    },
    showRecModal(state, action) {
      return { ...state, ...action.payload, recModalShow: true };
    },
    hideRecModal(state, action) {
      return { ...state, ...action.payload, recModalShow: false };
    },
    saveRecResult(state, action) {
      return { ...state, recommend: action.payload, recModalShow: false };
    },
    clearCache(state, action) {
      return { ...state, ...action.payload };
    },
  },
};
