import { query } from '../services/soldProduct';
import { message } from 'antd';
import modelExtend from 'dva-model-extend';
import queryString from 'query-string';
import { pageModel } from './common';
import { checkSearchParams } from '../utils/utils';
import { Codes, pageSize } from '../utils/config';

export default modelExtend(pageModel, {
  namespace: 'snapshot',

  state: {
    listLoading: false,
  },

  subscriptions: {
    setup({ dispatch, history }) {
      history.listen((location) => {
        if (location.pathname === '/sold') {
          const payload = checkSearchParams(queryString.parse(location.search));
          dispatch({
            type: 'query',
            payload,
          });
        }
      });
    }
  },

  effects: {
    * query ({ payload, callback }, { call, put }) {
      yield put({ type: 'changeLoading', payload: { listLoading: true }});
      const { data, success } = yield call(query, payload);
      if (success) {
        yield put({
          type: 'querySuccess',
          payload: {
            list: data.list,
            pagination: {
              current: Number(payload.pageNo) || 1,
              pageSize: Number(payload.pageSize) || pageSize,
              total: data.totalSize,
            }
          }
        });
      }
      yield put({ type: 'changeLoading', payload: { listLoading: false }});
    }
  },

  reducers: {
    changeLoading(state, action) {
      return { ...state, ...action.payload };
    },
  },
})
