import { queryOne, create, update } from '../../services/tag';
import pathToRegexp from 'path-to-regexp';
import { message } from 'antd';
import { Codes } from '../../utils/config';

export default {
  namespace: 'tagDetail',

  state: {
    filters: {},
    operType: 'create',
    currentItem: {},
    modalVisible: false,
    itemLoading: false,
  },

  subscriptions: {
    setup({ dispatch, history }) {
      history.listen(({ pathname, state, ...rest }) => {
        const match = pathToRegexp('/tag/tagItem/edit/:id').exec(pathname);
        if (match) {
          dispatch({ type: 'query', payload: { id: match[1] } });
          dispatch({ type: 'saveFilters', payload: state });
          dispatch({ type: 'saveOperType', payload: { operType: 'update' } });
        }
        if (pathname == '/tag/tagItem/add') {
          dispatch({ type: 'saveFilters', payload: state });
          dispatch({ type: 'saveOperType', payload: { operType: 'create' } });
        }
      });
    }
  },

  effects: {
    * query ({ payload }, { call, put }) {
      yield put({ type: 'changeLoading', payload: { itemLoading: true } });
      const { data, success } = yield call(queryOne, payload);
      if (success) {
        yield put({ type: 'querySuccess', payload: { ...data } });
      }
      yield put({ type: 'changeLoading', payload: { itemLoading: false } });
    },
    * create ({ payload, callback }, { call, put }) {
      const { data, success } = yield call(create, payload);
      if (success) {
        message.success('创建成功!');
        yield put({ type: 'initState' });
        if (callback) callback();
      }
    },
    * update ({ payload, callback }, { call, put }) {
      const { data, success } = yield call(update, payload);
      if (success) {
        message.success('修改成功!');
        yield put({ type: 'initState' });
        if (callback) callback();
      }
    },
  },

  reducers: {
    changeLoading(state, action) {
      return { ...state, ...action.payload };
    },
    querySuccess(state, action) {
      return {
        ...state,
        currentItem: action.payload,
      };
    },
    saveFilters(state, action) {
      return {
        ...state,
        filters: action.payload.filters,
      };
    },
    showModal(state, action) {
      return {
        ...state,
        ...action.payload,
        modalVisible: true,
      };
    },
    hideModal(state, action) {
      return {
        ...state,
        ...action.payload,
        modalVisible: false,
      };
    },
    saveOperType(state, action) {
      return { ...state, ...action.payload };
    },
    saveSortResult(state, action) {
      return {
        ...state,
        modalVisible: false,
        currentItem: {
          ...state.currentItem,
          itemList: action.payload.itemList,
        }
      };
    },
    initState(state) {
      return { ...state, currentItem: {}, itemLoading: false };
    }
  }
}
