import React, { Component } from 'react';
import moment from 'moment';
import { Modal, Table } from 'antd';

export default class CampusTableList extends Component {
  handleDeleteItem = (record) => {
    const { onDeleteItem } = this.props;
    Modal.confirm({
      title: '您确定要删除该校区吗?',
      onOk() {
        onDeleteItem(record.id);
      },
    });
  }

  render() {
    const {
      onDeleteItem,
      onEditItem,
      location,
      pagination,
      curMerchant,
      merchantList = [],
      ...tableProps
    } = this.props;

    const columns = [{
      title: '校区编号',
      dataIndex: 'code',
      key: 'code',
      width: '12%',
    }, {
      title: '校区名称',
      dataIndex: 'name',
      key: 'name',
      width: '34%',
    }, {
      title: '渠道名称',
      dataIndex: 'merchantId',
      key: 'merchantId',
      render: (text, record) => record.merchantName,
      filters: merchantList.map(item => ({ text: item.name, value: item.id })),
      filterMultiple: false,
      filteredValue: [curMerchant],
      width: '10%',
    }, {
      title: '联系人',
      dataIndex: 'contactName',
      key: 'contactName',
      width: '10%',
    }, {
      title: '电话',
      dataIndex: 'mobile',
      key: 'mobile',
      width: '12%',
    }, {
      title: '修改时间',
      dataIndex: 'gmtModified',
      key: 'gmtModified',
      render: text => (
        <div>{moment(text).format('YYYY-MM-DD HH:mm:ss')}</div>
      ),
      width: '16%',
    }, {
      title: '操作',
      dataIndex: 'operation',
      key: 'operation',
      render: (text, record) => (
        <div>
          <a onClick={() => onEditItem(record)}>编辑</a>
        </div>
      ),
      width: '6%',
    }];

    // 数据table列表表头的筛选按钮点击重置后merchantId值为空，此时删除该参数
    columns.map((item) => {
      item.dataIndex === 'merchantId' && !curMerchant ? delete item.filteredValue : null;
    });

    // 配置分页
    tableProps.pagination = !!pagination && { ...pagination, showSizeChanger: true, showQuickJumper: true, showTotal: total => `共 ${total} 条` };

    return (
      <Table
        simple
        bordered
        {...tableProps}
        columns={columns}
        rowKey={record => record.id}
      />
    );
  }
}
