import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import SelectModal from '../../../components/SelectModal';
import { Codes, productType } from '../../../utils/config';

export default class ProductSelectModal extends PureComponent {

  render() {
    const {
      rowKeyName,
      selTableData,
      modalVisible,
      onCancel,
      onOk,
      onSearch,
      fsFilteredValue,
      ...fsTableOpts
    } = this.props;

    const modalProps = {
      title: '选择产品',
      maskClosable: false,
      visible: modalVisible,
      onCancel,
      onOk,
    };

    const searchProps = {
      searchField: 'name',
      searchKeyWord: '',
      searchSize: 'default',
      searchSelect: true,
      searchSelectOptions: [{
        value: 'name', name: '产品名称', mode: 'input',
      },{
        value: 'code', name: '产品编号', mode: 'input',
      }],
      searchSelectProps: {
        defaultValue: 'code',
      },
      onSearch: (value) => onSearch(value),
    };

    //已选资源列表
    const selTableProps = {
      operDel: true,
      tablePagination: false,
      tableDataSource: selTableData,
      rowKeyName: rowKeyName,
      tableColumns: [{
        title: '编号',
        dataIndex: 'code',
        key: 'code',
        width: '25%',
      },{
        title: '名称',
        dataIndex: 'name',
        key: 'name',
        width: '25%',
      },{
        title: '类型',
        dataIndex: 'type',
        render: (text, record) => productType[text],
        width: '17%',
      },{
        title: '供应商',
        dataIndex: 'cpName',
        key: 'cpName',
        width: '17%',
      }]
    };

    //待选资源Table属性
    delete productType.PACKAGE;
    const fsTableProps = {
      fsTableColumns: [{
        title: '编号',
        dataIndex: 'code',
        key: 'code',
        width: '25%',
      },{
        title: '名称',
        dataIndex: 'name',
        key: 'name',
        width: '25%',
      },{
        title: '类型',
        dataIndex: 'type',
        render: (text, record) => (productType[record.type]),
        filters: Object.keys(productType).map(key => ({ text: productType[key], value: key })),
        filterMultiple: false,
        filteredValue: fsFilteredValue,
        width: '16%',
      },{
        title: '供应商',
        dataIndex: 'cpName',
        key: 'cpName',
        width: '17%',
      }],
      ...fsTableOpts,
    }

    return (
      <SelectModal
        mode="multiple"
        { ...searchProps }
        { ...selTableProps }
        { ...fsTableProps }
        { ...modalProps }
      />
    );
  }
}
