import React, { PureComponent } from 'react';
import queryString from 'query-string';
import { connect } from 'dva';
import { routerRedux } from 'dva/router';
import { Card } from 'antd';
import TableList from './table';
import Search from './search';
import RechargeModalForm from './modal';
import PageHeaderLayout from '../../../layouts/PageHeaderLayout';

@connect(state => ({ merchant: state.merchant }))
export default class Merchant extends PureComponent {
  render() {
    const { location, dispatch, merchant } = this.props;

    location.query = queryString.parse(location.search);
    const { query, pathname } = location;
    const { field, keyword, ...filters } = query;
    const { list, listLoading, pagination, modalVisible, currentItem } = merchant;

    // 把携带的参数中空值项删除
    Object.keys(filters).map((key) => { filters[key] ? null : delete filters[key]; });
    // 如果搜索内容不为空则添加进filters中
    if (field && keyword) {
      filters[field] = keyword;
    }

    const searchProps = {
      field,
      keyword,
      onSearch: (payload) => {
        if (!payload.keyword.length) {
          delete payload.field;
          delete payload.keyword;
        }
        dispatch(routerRedux.push({
          pathname,
          search: queryString.stringify({
            ...payload,
          }),
        }));
      },
      onAdd: () => {
        dispatch(
          routerRedux.push({
            pathname: '/merchant/add',
            state: filters,
          })
        );
      },
    };

    const modalProps = {
      item: currentItem,
      visible: modalVisible,
      maskClosable: false,
      title: '账户充值',
      wrapClassName: 'vertical-center-modal',
      onOk(data) {
        dispatch({
          type: 'merchant/recharge',
          payload: data,
          callback: () => {
            dispatch(routerRedux.push({
              pathname: '/trade/order',
              search: queryString.stringify(filters),
            }));
          },
        });
      },
      onCancel() {
        dispatch({
          type: 'merchant/hideModal',
        });
      },
    };

    const listProps = {
      pagination,
      location,
      modalVisible,
      dataSource: list,
      loading: listLoading,
      curDomain: filters.domain,
      curStatus: filters.status,
      onChange: (pagination, filterArgs) => {
        const getValue = obj => Object.keys(obj).map(key => obj[key]).join(',');
        const tableFilters = Object.keys(filterArgs).reduce((obj, key) => {
          const newObj = { ...obj };
          newObj[key] = getValue(filterArgs[key]);
          return newObj;
        }, {});
        const data = { ...filters, ...tableFilters };
        Object.keys(data).map(key => (data[key] ? null : delete data[key]));
        dispatch(routerRedux.push({
          pathname,
          search: queryString.stringify({
            ...data,
            pageNo: pagination.current,
            pageSize: pagination.pageSize,
          }),
        }));
      },
      onEditItem: (item) => {
        dispatch(
          routerRedux.push({
            pathname: `/merchant/edit/${item.id}`,
            state: filters,
          })
        );
      },
      onDeleteItem: (id) => {
        dispatch({
          type: 'merchant/delete',
          payload: id,
          callback: () => {
            dispatch(
              routerRedux.push({
                pathname,
                search: queryString.stringify(filters),
              })
            );
          },
        });
      },
      onRechargeItem: (record) => {
        dispatch({
          type: 'merchant/showModal',
          payload: record,
        });
      },
    };

    return (
      <PageHeaderLayout>
        <Card>
          <Search {...searchProps} />
          <TableList {...listProps} />
          <RechargeModalForm {...modalProps} />
        </Card>
      </PageHeaderLayout>
    );
  }
}
