import React, { PureComponent } from 'react';
import moment from 'moment';
import { Divider, Modal, Table, Badge } from 'antd';
import { domains, statuses, Codes } from '../../../utils/config';
import { getLocalUser } from '../../../utils/helper';

export default class TableList extends PureComponent {
  /**
   * 删除操作
   */
  handleDeleteItem = (record) => {
    const { onDeleteItem } = this.props;
    Modal.confirm({
      okText: '确定',
      cancelText: '取消',
      title: '您确定要删除该厂商?',
      onOk: () => onDeleteItem({ id: record.id }),
    });
  }

  /**
   * 充值操作(只有userid=1的用户才展示充值按钮)
   */
  handleRechargeItem = (record) => {
    const { onRechargeItem } = this.props;
    onRechargeItem(record);
  }

  render() {
    const {
      curDomain,
      curStatus,
      onDeleteItem,
      onEditItem,
      pagination,
      modalVisible,
      form,
      ...tableProps
    } = this.props;

    const formItemLayout = {
      labelCol: { span: 7 },
      wrapperCol: { span: 24 },
    };

    const columns = [{
      title: '厂商编号',
      dataIndex: 'code',
      key: 'code',
      width: '14%',
    }, {
      title: '厂商名称',
      dataIndex: 'name',
      key: 'name',
      width: '14%',
    }, {
      title: '厂商类型',
      dataIndex: 'domain',
      key: 'domain',
      render: (text, record) => (
        <div>{domains[record.domain]}</div>
      ),
      filters: Object.keys(domains).map(key => ({ text: domains[key], value: key })),
      filterMultiple: false,
      filteredValue: [curDomain],
      width: '14%',
    }, {
      title: '账户余额(¥)',
      dataIndex: 'balance',
      key: 'balance',
      width: '12%',
    }, {
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      render: (text, record) => {
        const statusMap = { [Codes.CODE_NORMAL]: 'success', [Codes.CODE_DELETE]: 'error' };
        return (<Badge status={statusMap[record.status]} text={statuses[record.status]} />);
      },
      filters: Object.keys(statuses).map(key => ({ text: statuses[key], value: key })),
      filterMultiple: false,
      filteredValue: [curStatus],
      width: '14%',
    }, {
      title: '修改时间',
      dataIndex: 'gmtModified',
      key: 'gmtModified',
      render: text => (
        <div>{moment(text).format('YYYY-MM-DD HH:mm:ss')}</div>
      ),
    }, {
      title: '操作',
      dataIndex: 'operation',
      key: 'operation',
      render: (text, record) => {
        if (getLocalUser().id === '1') {
          return (
            <div>
              <a onClick={() => onEditItem(record)}>编辑</a>
              <Divider type="vertical" />
              <a onClick={() => this.handleRechargeItem(record)}>充值</a>
              <Divider type="vertical" />
              <a onClick={() => this.handleDeleteItem(record)}>删除</a>
            </div>
          );
        } else {
          return (
            <div>
              <a onClick={() => onEditItem(record)}>编辑</a>
              <Divider type="vertical" />
              <a onClick={() => this.handleDeleteItem(record)}>删除</a>
            </div>
          );
        }
      },
      width: '15%',
    }];

    // 数据table列表表头的筛选按钮点击重置后status与domain值为空，此时删除该参数
    columns.map((item) => {
      item.dataIndex === 'status' && !curStatus ? delete item.filteredValue : null;
      item.dataIndex === 'domain' && !curDomain ? delete item.filteredValue : null;
    });

    // 配置分页
    tableProps.pagination = !!pagination && { ...pagination, showSizeChanger: true, showQuickJumper: true, showTotal: total => `共 ${total} 条` };

    return (
      <Table
        simple
        bordered
        {...tableProps}
        columns={columns}
        rowKey={record => record.id}
      />
    );
  }
}
