import React, { PureComponent } from 'react';
import SelectModal from '../../../components/SelectModal';
import { productType } from '../../../utils/config';

export default class MerchantProductSelectModal extends PureComponent {

  render() {
    const { selTableData, modalVisible, rowKeyName, onCancel, onOk, onSearch, ...fsTableOpts } = this.props;

    const modalProps = {
      title: '选则商品',
      maskClosable: false,
      visible: modalVisible,
      onCancel,
      onOk,
    };

    const searchProps = {
      searchField: 'name',
      searchKeyWord: '',
      searchSize: 'default',
      searchSelect: true,
      searchSelectOptions: [{
        value: 'name', name: '产品名称', mode: 'input',
      },{
        value: 'code', name: '产品编号', mode: 'input',
      }],
      searchSelectProps: {
        defaultValue: 'name',
      },
      onSearch: (value) => {
        onSearch(value);
      },
    };

    const selTableProps = {
      operDel: true,
      tablePagination: false,
      tableDataSource: selTableData,
      rowKeyName: rowKeyName,
      tableColumns: [{
        title: '产品编号',
        dataIndex: 'code',
        key: 1,
        width: '27%',
      },{
        title: '产品名称',
        dataIndex: 'name',
        key: 2,
        width: '28%'
      },{
        title: '产品类型',
        dataIndex: 'type',
        key: 3,
        render: (text, record) => productType[text],
        width: '15%'
      },{
        title: '渠道名称',
        dataIndex: 'merchantName',
        key: 4,
        width: '15%',
      }],
    };

    const fsTableProps = {
      fsTableColumns: [{
        title: '产品编号',
        dataIndex: 'code',
        key: 1,
        width: '27%',
      },{
        title: '产品名称',
        dataIndex: 'name',
        key: 2,
        width: '28%',
      },{
        title: '产品类型',
        dataIndex: 'type',
        key: 3,
        render: (text, record) => productType[text],
        width: '15%',
      },{
        title: '渠道名称',
        dataIndex: 'merchantName',
        key: 4,
        width: '15%',
      }],
      ...fsTableOpts,
    }

    return (
      <SelectModal
        mode="multiple"
        { ...searchProps }
        { ...modalProps }
        { ...selTableProps }
        { ...fsTableProps }
      />
    );
  }
}

// import React, { PureComponent } from 'react';
// import { Modal, List, Collapse, Card, Avatar, Input } from 'antd';
//
// const { Panel } = Collapse;
// export default class GoodsSelectModal extends PureComponent {
//   render() {
//     const { modalVisible, onCancel, onOk, pagination, dataSource, ...restProps } = this.props;
//     return (
//       <Modal
//         title="添加商品"
//         visible={modalVisible}
//         onOk={onOk}
//         onCancel={onCancel}
//         {...restProps}
//       >
//         <List
//           size="large"
//           bordered
//           grid={{ gutter: 16, column: 2 }}
//           pagination={pagination}
//           dataSource={dataSource}
//           renderItem={item =>
//             <List.Item
//             >
//               <Card title={item.code}>
//
//               </Card>
//             </List.Item>
//           }
//         />
//       </Modal>
//     );
//   }
// }
