import React, { PureComponent } from 'react';
import moment from 'moment';
import { Table, Badge } from 'antd';
import { orderStatuses, Codes } from '../../../utils/config';
import { provCodeToName } from '../../../utils/city';

export default class TableList extends PureComponent {
  handleItemView = (record) => {
    const { onViewItem } = this.props;
    onViewItem(record);
  }

  render() {
    const { dataSource, pagination, ...tableProps } = this.props;
    const newDataSource = [...dataSource];
    newDataSource.forEach((item) => {
      if (Array.isArray(item.detailList) && item.detailList.length) {
        item.children = item.detailList.map(one => (
          {
            ...one,
            flag: true,
            userCode: item.userCode,
            provinceCode: item.provinceCode,
            cityName: item.cityName,
            zoneName: item.zoneName,
          })
        );
      }
    });

    const columns = [{
      title: '订单编号',
      dataIndex: 'id',
      key: 'id',
      fixed: 'left',
      width: 330,
    }, {
      title: '终端编号',
      dataIndex: 'userCode',
      key: 'userCode',
    }, {
      title: '校区',
      dataIndex: 'campusName',
      key: 'campusName',
      render: (text, record) => (
        <span>{`${provCodeToName(record.provinceCode)}-${record.cityName}-${record.zoneName}`}</span>
      ),
    }, {
      title: '商品总价(元)',
      dataIndex: 'originPrice',
      key: 'originPrice',
    }, {
      title: '优惠价格(元)',
      dataIndex: 'adjustPrice',
      key: 'adjustPrice',
    }, {
      title: '实际售价(元)',
      dataIndex: 'finalPrice',
      key: 'finalPrice',
    }, {
      title: '状态',
      dataIndex: 'orderStatus',
      key: 'orderStatus',
      render: (text, record) => {
        const statusMap = {
          [Codes.CODE_UNPAID]: 'default',
          [Codes.CODE_COMPLETE]: 'success',
          [Codes.CODE_CANCEL]: 'error',
        };
        return (<Badge status={statusMap[record.orderStatus] || 'processing'} text={orderStatuses[record.orderStatus]} />);
      },
    }, {
      title: '下单时间',
      dataIndex: 'gmtCreated',
      key: 'gmtCreated',
      render: text => (
        <div>{moment(text).format('YYYY-MM-DD HH:mm:ss')}</div>
      ),
    }, {
      title: '操作',
      dataIndex: 'operation',
      key: 'operation',
      render: (text, record) => (
        <div>
          <a onClick={() => this.handleItemView(record)}>查看</a>
        </div>
      ),
      width: 70,
      fixed: 'right',
    }];

    // 配置分页
    tableProps.pagination = !!pagination && { ...pagination, showSizeChanger: true, showQuickJumper: true, showTotal: total => `共 ${total} 条` };

    return (
      <Table
        simple
        bordered
        dataSource={newDataSource}
        columns={columns}
        rowKey={record => record.id}
        {...tableProps}
        scroll={{ x: 1500 }}
      />
    );
  }
}
