import React, { PureComponent } from 'react';
import PropTypes from 'prop-types';
import { message, Form, Switch, Input, Modal } from 'antd';
import Uploader from '../../../components/Uploader';
import { Codes, statuses } from '../../../utils/config';

@Form.create()
export default class ModalForm extends PureComponent {
  // 图片上传成功
  handleSingleUpload = (file, fileName, signature) => {
    const { onUpload, onRemove } = this.props;
    if (file) {
      const separatorIndex = file.name.lastIndexOf('.');
      const name = file.name.substring(0, separatorIndex);
      const suffix = file.name.substring(separatorIndex + 1, file.name.length);
      const data = {
        name,
        format: suffix,
        size: file.size,
        code: name,
        path: `${signature.dir}${fileName}`,
        url: `${signature.host}/${signature.dir}${fileName}`,
      };
      message.success('图片上传成功!');
      onUpload(data);
    } else {
      // 图片被移除
      const data = { format: null, size: null, url: null, path: null };
      onRemove(data);
    }
  }

  handleOk = () => {
    const {
      form: {
        validateFields,
        getFieldsValue,
        resetFields,
      },
      item,
      onOk,
      modalType,
    } = this.props;
    validateFields((errors) => {
      if (errors) return;
      const data = { ...getFieldsValue() };
      if (modalType == 'update') {
        const { id, status, type } = item;
        data.id = id;
        data.type = type;
        data.status = status;
      } else if (modalType == 'create') {
        data.status = Codes.CODE_NORMAL; // 创建图片，默认状态status="NORAML"
        data.type = Codes.CODE_IMAGE;  // 创建图片，默认类型type=3
      }
      onOk(data);
      resetFields();
    });
  }

  handleCancel = () => {
    const { onCancel, form } = this.props;
    const { resetFields } = form;
    onCancel();
    resetFields();
  }

  render() {
    const { item, signature, form, ...modalProps } = this.props;
    const { getFieldDecorator } = form;
    const { code, name, format, size, url, path } = item;

    const formItemLayout = {
      labelCol: {
        span: 7,
      },
      wrapperCol: {
        span: 14,
      },
    };

    const modalOpts = {
      ...modalProps,
      onOk: this.handleOk,
      onCancel: this.handleCancel,
    };

    return (
      <Modal {...modalOpts}>
        <Form layout="horizontal">
          <Form.Item label="单图上传" {...formItemLayout}>
            <Uploader
              accept="image"
              files={url}
              signature={signature}
              onUpload={::this.handleSingleUpload}
            />
          </Form.Item>
          <Form.Item label="图片编号：" hasFeedback {...formItemLayout}>
            {getFieldDecorator('code', {
              rules: [{ required: true, type: 'string', message: "此项为必填项!" }],
              initialValue: code,
            })(<Input />)}
          </Form.Item>
          <Form.Item label="图片名称：" hasFeedback {...formItemLayout}>
            {getFieldDecorator('name', {
              rules: [{ required: true, type: 'string', message: "此项为必填项!" }],
              initialValue: name,
            })(<Input />)}
          </Form.Item>
          <Form.Item label="图片路径：" hasFeedback {...formItemLayout}>
            {getFieldDecorator('path', {
              rules: [{ required: true, type: 'string', message: "此项为必填项!" }],
              initialValue: path,
            })(<Input placeholder="上传图片后自动生成"/>)}
          </Form.Item>
          <Form.Item label="图片格式：" {...formItemLayout}>
            {getFieldDecorator('format', {
              initialValue: format,
            })(<Input placeholder="上传图片后自动生成" />)}
          </Form.Item>
          <Form.Item label="图片大小：" {...formItemLayout}>
            {getFieldDecorator('size', {
              initialValue: size,
            })(<Input placeholder="上传图片后自动生成" suffix={"字节"} />)}
          </Form.Item>
        </Form>
      </Modal>
    );
  }
}
