import React, { PureComponent } from 'react';
import { Badge } from 'antd';
import SelectModal from '../../../components/SelectModal';
import { Codes, tagType, itemStatuses } from '../../../utils/config';

export default class ItemSortModal extends PureComponent {
  render() {
    const { itemList, modalVisible, rowKeyName, onCancel, onOk } = this.props;
    const modalProps = {
      title: '商品排序',
      maskClosable: false,
      visible: modalVisible,
      onCancel,
      onOk,
    };
    const selTableProps = {
      operSort: true,
      tablePagination: false,
      tableDataSource: itemList,
      rowKeyName: rowKeyName,
      tableColumns: [{
        title: '位置',
        dataIndex: 'sort',
        key: 'sort',
      },{
        title: '商品名称',
        dataIndex: 'name',
        key: 'name',
      },{
        title: '商品状态',
        dataIndex: 'status',
        key: 'status',
        render: (text, record) => {
          const statusMap = {[Codes.CODE_SALE]: 'success', [Codes.CODE_DELETE]: 'error'};
          return (<Badge status={statusMap[record.status]} text={itemStatuses[record.status]} />);
        },
      },{
        title: '商品类型',
        dataIndex: 'type',
        key: 'type',
        render: (text, record) => (<span>{tagType[record.type]}</span>),
      }],
    };

    return (
      <SelectModal
        mode="sort"
        { ...modalProps }
        { ...selTableProps }
      />
    );
  }
}
