import React, { PureComponent } from 'react';
import moment from 'moment';
import { Divider, Modal, Table, Menu, Icon, Badge } from 'antd';
import { statuses, Codes } from '../../../utils/config';

export default class TableList extends PureComponent {

  handleDeleteItem = (record) => {
    const { onDeleteItem } = this.props;
    Modal.confirm({
      title: `您确定要删除该标签组?`,
      okText: '确定',
      cancelText: '取消',
      onOk: () => onDeleteItem({id: record.id}),
    });
  }

  render() {
    const { curMerchant, merchantList, onDeleteItem, onEditItem, pagination, ...tableProps } = this.props;

    const columns = [{
      title: '标签组编号',
      dataIndex: 'code',
      key: 'code',
      width: '20%',
    },{
      title: '标签组名称',
      dataIndex: 'name',
      key: 'name',
      width: '20%',
    },{
      title: '渠道名称',
      dataIndex: 'merchantId',
      key: 'merchantId',
      render: (text, record) => record.merchantName,
      filters: merchantList.map(item => ({ text: item.name, value: item.id })),
      filterMultiple: false,
      filteredValue: [curMerchant],
      width: '15%',
    },{
      title: '状态',
      dataIndex: 'status',
      key: 'status',
      render: (text, record) => {
        const statusMap = {[Codes.CODE_NORMAL]: 'success', [Codes.CODE_DELETE]: 'error'};
        return (<Badge status={statusMap[record.status]} text={statuses[record.status]} />);
      },
      width: '15%',
    },{
      title: '修改时间',
      dataIndex: 'gmtModified',
      key: 'gmtModified',
      render: (text, record) => (
        <div>{moment(text).format('YYYY-MM-DD HH:mm:ss')}</div>
      ),
      width: '18%',
    },{
      title: '操作',
      dataIndex: 'operation',
      key: 'operation',
      render: (text, record) => (
        <div>
          <a onClick={() => onEditItem(record)}>编辑</a>
          <Divider type="vertical" />
          <a onClick={() => this.handleDeleteItem(record)}>删除</a>
        </div>
      ),
      width: '12%',
    }];

    // 数据table列表表头的筛选按钮点击重置后status与domain值为空，此时删除该参数
    columns.map(item => {
      item.dataIndex === 'merchantId' && !curMerchant ? delete item.filteredValue : null;
    });

    // 配置分页
    tableProps.pagination = !!pagination && { ...pagination, showSizeChanger: true, showQuickJumper: true, showTotal: total => `共 ${total} 条`};

    return (
      <Table
        simple
        bordered
        { ...tableProps }
        columns={columns}
        rowKey={record => record.id}
      />
    );
  }
}
