import React, { PureComponent } from 'react';
import { Popover, Icon } from 'antd';
import SelectModal from '../../../components/SelectModal';
import styles from './modal.less';
import { Codes, resourceType, ossHost } from '../../../utils/config';

export default class ResourceSelectSortModal extends PureComponent {
  render() {
    const {
      selTableData,
      modalVisible,
      rowKeyName,
      fsFilteredValue,
      onCancel,
      onOk,
      onSearch,
      ...fsTableOpts,
    } = this.props;


    const modalProps = {
      title: '选择资源',
      maskClosable: false,
      visible: modalVisible,
      onCancel,
      onOk,
    };

    const searchProps = {
      searchField: 'name',
      searchKeyWord: '',
      searchSize: 'default',
      searchSelect: true,
      searchSelectOptions: [{
        value: 'name', name: '资源名称', mode: 'input',
      },{
        value: 'code', name: '资源编号', mode: 'input',
      }],
      searchSelectProps: {
        defaultValue: 'code',
      },
      onSearch: (value) => onSearch(value),
    };

    const selTableProps = {
      operDel: true,
      operSort: true,
      tableClassName: styles.sTable,
      tablePagination: false,
      tableDataSource: selTableData,
      rowKeyName: rowKeyName,
      tableColumns: [{
        title: '缩略图',
        dataIndex: 'url',
        key: 'url',
        render: (text, record) => (
          record.type !== Codes.CODE_IMAGE ?
            <Icon type="video-camera" style={{ fontSize: 40}} />
          :
            <Popover
              content={<img alt="" src={`${ossHost}/${record.path}`} width={250} />}
              title={record.name}
            >
              <img alt="" src={`${ossHost}/${record.path}`} width={70} />
            </Popover>
        ),
      },{
        title: '资源编号',
        dataIndex: 'code',
        key: 'code',
      },{
        title: '资源名称',
        dataIndex: 'name',
        key: 'name',
      },{
        title: '类型',
        dataIndex: 'type',
        key: 'type',
        render: (text, record) => (resourceType[record.type]),
      }],
    };

    //待选资源Table属性
    const fsTableProps = {
      fsTableClassName: styles.fsTable,
      fsTableColumns: [{
        title: '缩略图',
        dataIndex: 'url',
        key: 'url',
        render: (text, record) => (
          record.type !== Codes.CODE_IMAGE ?
            <Icon type="video-camera" style={{ fontSize: 40}} />
          :
            <Popover
              content={<img alt="" src={`${ossHost}/${record.path}`} width={250} />}
              title={record.name}
              placement="top"
            >
              <img alt="" src={`${ossHost}/${record.path}`} width={70} />
            </Popover>
        ),
      },{
        title: '资源编号',
        dataIndex: 'code',
        key: 'code',
      },{
        title: '资源名称',
        dataIndex: 'name',
        key: 'name',
      },{
        title: '类型',
        dataIndex: 'type',
        key: 'type',
        render: (text, record) => (resourceType[record.type]),
        filters: Object.keys(resourceType).map(key => ({ text: resourceType[key], value: key })),
        filterMultiple: false,
        filteredValue: fsFilteredValue,
      }],
      ...fsTableOpts,
    }

    return (
      <SelectModal
        mode="multiple"
        { ...searchProps }
        { ...modalProps }
        { ...selTableProps }
        { ...fsTableProps }
      />
    );
  }
}
